@@ -3,7 +3,6 @@
 
 """|UDM| module for the client maintenance policies"""
 
-from logging import getLogger
 
 import univention.admin.cron
 import univention.admin.filter
@@ -17,7 +16,6 @@ from univention.admin.policy import (
 )
 
 
-log = getLogger('ADMIN')
 translation = univention.admin.localization.translation('univention.admin.handlers.policies')
 _ = translation.translate
 
@@ -160,7 +158,7 @@ class object(univention.admin.handlers.simplePolicy):
 
     def parse_cron(self, cronstring):
         # don't use self[key] inside here - it will be recursive call(ed by) __getitem__
-        log.debug('maintenance cron: %s', cronstring)
+        self.log.debug('parse cron', value=cronstring)
         cron = univention.admin.cron.cron_split(cronstring)
         keys = ['minute', 'hour', 'day', 'month', 'weekday']
         for key in keys:
